==================
``psyclone.parse``
==================

.. automodule:: psyclone.parse

   .. contents::
      :local:


Submodules
==========

.. toctree::

   psyclone.parse.algorithm
   psyclone.parse.kernel
   psyclone.parse.utils

.. currentmodule:: psyclone.parse
